@@ -10,7 +10,7 @@ import net.argius.frui.*;
  */
 public class PrintSuffixSet extends Print {
 
-    private final HashSet set;
+    private final Set set;
 
     /**
      * PrintSuffixSet̐B
